QueryCache

Struct QueryCache 

pub struct QueryCache { /* private fields */ }

Implementations

Source

impl QueryCache

pub fn new(store: ChunkStoreHandle) -> Self

pub fn new_handle(store: ChunkStoreHandle) -> QueryCacheHandle

pub fn clear(&self)

Source

impl QueryCache

pub fn stats(&self) -> QueryCachesStats

Computes the stats for all primary caches.

Source

impl QueryCache

pub fn latest_all( &self, tracking_mode: ChunkTrackingMode, query: &LatestAtQuery, entity_path: &EntityPath, components: impl IntoIterator<Item = ComponentIdentifier>, ) -> LatestAllResults

Like Self::latest_at, but may return multiple rows for each component, if those rows were all logged with the exact same TimeInt.

For instance: if you log many transforms to the same entity on the same timestep, only one of them will show up in a latest-at query, but all in a latest-all.

In case of static data, only ONE value will ever be returned. This is because the store only ever keeps the last static value of everything. This, in turn, is because some users log e.g. a video stream as one static image after the other.

Source

impl QueryCache

pub fn latest_at( &self, report_mode: ChunkTrackingMode, query: &LatestAtQuery, entity_path: &EntityPath, components: impl IntoIterator<Item = ComponentIdentifier>, ) -> LatestAtResults

Queries for the given ComponentIdentifiers using latest-at semantics.

See LatestAtResults for more information about how to handle the results.

This is a cached API – data will be lazily cached upon access.

pub fn gc(&self, target: GarbageCollectionTarget)

Free up some RAM by forgetting the older parts of all timelines.

Source

impl QueryCache

pub fn range( &self, tracking_mode: ChunkTrackingMode, query: &RangeQuery, entity_path: &EntityPath, components: impl IntoIterator<Item = ComponentIdentifier>, ) -> RangeResults

Queries for the given components using range semantics.

See RangeResults for more information about how to handle the results.

This is a cached API – data will be lazily cached upon access. The returned chunks preserve the original ChunkIds from the source ChunkStore, even though re_chunk::Chunk::range internally creates new IDs when slicing. This is important so that VideoStreamCache can track which physical chunks are in use.