RangeResults

Struct RangeResults 

pub struct RangeResults {
    pub query: RangeQuery,
    pub missing_virtual: Vec<ChunkId>,
    pub components: IntMap<ComponentIdentifier, Vec<Chunk>>,
}
Results for a range query.

The data is both deserialized and resolved/converted.

Use RangeResults::get or RangeResults::get_required in order to access the results for each individual component.

Since the introduction of virtual/offloaded chunks, it is possible for a query to detect that it is missing some data in order to compute accurate results. This lack of data is communicated using a non-empty RangeResults::missing_virtual field.

Fields

query: RangeQuery

The query that yielded these results.

missing_virtual: Vec<ChunkId>

The relevant virtual chunks that were found for this query.

Until these chunks have been fetched and inserted into the appropriate ChunkStore, the results of this query cannot accurately be computed.

Note, these are NOT necessarily root chunks. Use ChunkStore::find_root_chunks to get those.

components: IntMap<ComponentIdentifier, Vec<Chunk>>

Results for each individual component.

Implementations

Source

impl RangeResults

pub fn is_partial(&self) -> bool

Returns true if these are partial results.

Partial results happen when some of the chunks required to accurately compute the query are currently missing/offloaded. It is then the responsibility of the caller to look into the missing chunk IDs, fetch them, load them, and then try the query again.

pub fn is_empty(&self) -> bool

Returns true if the results are completely empty.

I.e. neither physical/loaded nor virtual/offloaded chunks could be found.

pub fn get(&self, component: ComponentIdentifier) -> Option<&[Chunk]>

Returns the Chunks for the specified component.

pub fn get_required(&self, component: ComponentIdentifier) -> Result<&[Chunk]>

Returns the Chunks for the specified component.

Returns an error if the component is not present.